@@ -7,7 +7,7 @@ use warnings;
 use Moo::Role;
 use namespace::autoclean;
 
-our $VERSION = '0.046'; # VERSION
+our $VERSION = '0.047'; # VERSION
 our $AUTHORITY = 'cpan:IMAGO'; # AUTHORITY
 
 requires 'available_methods';
@@ -26,7 +26,7 @@ Regru::API::Role::Namespace - something that can treat as a namespace
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 SYNOPSIS
 
@@ -56,7 +56,7 @@ L<Regru::API::Role::Client>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/regru/regru-api-perl/issues
+L<https://github.com/regru/regru-api-perl/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
